(big cummies) is an example of uploading a package to pypi.org
==============================================================

PyPi: https://pypi.org/project/bigcummies/

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install bigcummies

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   if __name__ == '__main__':
       my = Profile('Cum')
       my.company = 'pusspuss'
       my.hobby = ['Youtuber','Reading','Sleeping']
       print(my.name)
       my.show_email()
       my.show_myart()
       my.show_hobby()

พัฒนาโดย: ลุงวิศวกร สอนคำนวณ FB: https://www.facebook.com/UncleEngineer
YouTube: https://www.youtube.com/UncleEngineer
